# -*- coding: utf-8 -*-
#
# Copyright 2011-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The user interface for the control panel for Ubuntu One."""

from PyQt4 import QtGui, QtCore

from ubuntuone.controlpanel.gui.qt.systray import TrayIcon
from ubuntuone.controlpanel.gui.qt.ui import mainwindow_ui


class MainWindow(QtGui.QMainWindow):
    """The Main Window of the Control Panel."""

    def __init__(self, close_callback=None):
        """Initialize this instance with the UI layout."""
        super(MainWindow, self).__init__()
        self.ui = mainwindow_ui.Ui_MainWindow()
        self.ui.setupUi(self)
        self.close_callback = close_callback
        self._setup()
        self.quit_action = QtGui.QAction(self,
            triggered=self.close)
        self.quit_action.setShortcuts(["Ctrl+q", "Ctrl+w"])
        self.addAction(self.quit_action)

    def _setup(self):
        """Do some extra setupping for the UI."""
        self.ui.control_panel.finished.connect(self.close)

    # Invalid name "closeEvent"
    # pylint: disable=C0103

    def closeEvent(self, event):
        """The main window is being closed, call any custom callback."""
        if self.close_callback is not None:
            self.close_callback()
        event.accept()

    # pylint: enable=C0103


def start(close_callback, minimized=False, with_icon=False):
    """Show the UI elements."""
    # pylint: disable=W0404, F0401
    if not minimized:
        if with_icon or minimized:
            window = MainWindow()
        else:
            window = MainWindow(close_callback=close_callback)
        app = QtGui.QApplication.instance()
        style = QtGui.QStyle.alignedRect(
                    QtCore.Qt.LeftToRight, QtCore.Qt.AlignCenter,
                    window.size(), app.desktop().availableGeometry())
        window.setGeometry(style)
        window.show()
    else:
        window = None
    if with_icon or minimized:
        QtGui.QApplication.instance().setQuitOnLastWindowClosed(False)
        icon = TrayIcon(window=window, close_callback=close_callback)
    else:
        icon = None
    return icon, window
